==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/FormatSummaryTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSummaryTextEventArgsDescription } from "./FormatSummaryTextEventArgsDescription";
/**
 * @hidden
 */
export let FormatSummaryTextEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatSummaryTextEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FormatSummaryTextEventArgsDescriptionMetadata.a == null) {
                FormatSummaryTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatSummaryTextEventArgsDescriptionMetadata.c(FormatSummaryTextEventArgsDescriptionMetadata.a);
            }
            if (a.k(FormatSummaryTextEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(FormatSummaryTextEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("DisplayName", "String");
            a.item("SummaryResultRef", "(w:SummaryResult,wf:SummaryResult)DataRef");
            a.item("FormattedResult", "String");
            a.item("FormattedText", "String");
        }
        static d(a) {
            FormatSummaryTextEventArgsDescriptionMetadata.b(a);
            a.ad("FormatSummaryTextEventArgs", () => new FormatSummaryTextEventArgsDescription());
            a.ac("FormatSummaryTextEventArgs", FormatSummaryTextEventArgsDescriptionMetadata.a);
        }
    }
    FormatSummaryTextEventArgsDescriptionMetadata.$t = markType(FormatSummaryTextEventArgsDescriptionMetadata, 'FormatSummaryTextEventArgsDescriptionMetadata');
    FormatSummaryTextEventArgsDescriptionMetadata.a = null;
    return FormatSummaryTextEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/FormatSummaryTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSummaryTextEventArgsDescription } from "./FormatSummaryTextEventArgsDescription";
/**
 * @hidden
 */
export let FormatSummaryTextEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatSummaryTextEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FormatSummaryTextEventArgsDescriptionMetadata.a == null) {
                FormatSummaryTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatSummaryTextEventArgsDescriptionMetadata.c(FormatSummaryTextEventArgsDescriptionMetadata.a);
            }
            if (a.k(FormatSummaryTextEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(FormatSummaryTextEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("DisplayName", "String");
            a.item("SummaryResultRef", "(w:SummaryResult,wf:SummaryResult)DataRef");
            a.item("FormattedResult", "String");
            a.item("FormattedText", "String");
        }
        static d(a) {
            FormatSummaryTextEventArgsDescriptionMetadata.b(a);
            a.ae("FormatSummaryTextEventArgs", () => new FormatSummaryTextEventArgsDescription());
            a.ad("FormatSummaryTextEventArgs", FormatSummaryTextEventArgsDescriptionMetadata.a);
        }
    }
    FormatSummaryTextEventArgsDescriptionMetadata.$t = markType(FormatSummaryTextEventArgsDescriptionMetadata, 'FormatSummaryTextEventArgsDescriptionMetadata');
    FormatSummaryTextEventArgsDescriptionMetadata.a = null;
    return FormatSummaryTextEventArgsDescriptionMetadata;
})();
